# Promplate Compile

Compile your template into standalone python file, and you can use it without `promplate` installed.

And the **context** parameter is fully typed, which means you can get auto-completion in your IDE using templates' `render` method.
